/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.batchee.cdi.impl;

import org.apache.batchee.cdi.scope.StepScoped;

import java.lang.annotation.Annotation;

import jakarta.batch.runtime.context.StepContext;
import jakarta.enterprise.inject.Typed;
import jakarta.enterprise.inject.spi.BeanManager;

@Typed
public class StepContextImpl extends BaseContext {


    StepContextImpl(BeanManager bm) {
        super(bm);
    }


    @Override
    public Class<? extends Annotation> getScope() {
        return StepScoped.class;
    }

    @Override
    protected Long currentKey() {
        StepContext stepContext = getContextResolver().getStepContext();
        if (stepContext == null) {
            return null;
        }

        return stepContext.getStepExecutionId();
    }

    public void exitStep() {
        endContext(currentKey());
    }


}
